#include <iostream>
#include <vector>
#include <set>

using namespace std;

struct Rect {
    long long x0, y0, x1, y1;

    Rect(long long x0, long long y0, long long x1, long long y1) {
        this->x0 = x0;
        this->y0 = y0;
        this->x1 = x1;
        this->y1 = y1;
    }

    vector<Rect> split(Rect r) {
        vector<Rect> ans;

        if(r.x0 - x0 != 0) {
            ans.push_back(Rect(x0, y0, r.x0, y1));
        }

        if(x1 - r.x1 != 0) {
            ans.push_back(Rect(r.x1, y0, x1, y1));
        }

        if(r.y0 - y0 != 0) {
            ans.push_back(Rect(r.x0, y0, r.x1, r.y0));
        }

        if(y1 - r.y1 != 0) {
            ans.push_back(Rect(r.x0, r.y1, r.x1, y1));
        }

        return ans;
    }

    Rect getCross(Rect r) {
        Rect ar = Rect(max(x0, r.x0), max(y0, r.y0), min(x1, r.x1), min(y1, r.y1));

        if(ar.x0 >= ar.x1 || ar.y0 >= ar.y1) {
            return Rect(0, 0, 0, 0);
        }

        return ar;
    }
};

int main() {
    int k, n;
    cin >> k >> n;

    bool f = true;
    set<pair<long long, long long>> setRec;

    vector<Rect> rectangles;
    long long curX = 0;
    long long curY = 0;

    for (int i = 0; i < n; ++i) {
        char di;
        int ai;

        cin >> di >> ai;

        if(ai != k) {
            f = false;
        }

        Rect r = Rect(0, 0, 0, 0);

        if (di == 'N') {
            r = Rect(curX, curY, curX + k, curY + ai + k);
            curY = curY + ai;
        } else if (di == 'S') {
            r = Rect(curX, curY - ai, curX + k, curY + k);
            curY = curY - ai;
        } else if (di == 'W') {
            r = Rect(curX - ai, curY, curX + k, curY + k);
            curX = curX - ai;
        } else {
            r = Rect(curX, curY, curX + ai + k, curY + k);
            curX = curX + ai;
        }

        if(!f) {
            int size = rectangles.size();

            for (int j = 0; j < size; ++j) {
                Rect cross = rectangles[j].getCross(r);

                if (cross.x0 == 0 && cross.x1 == 0) {
                    continue;
                }

                vector<Rect> splittedRj = rectangles[j].split(cross);

                if (splittedRj.size() == 0) {
                    rectangles[j] = Rect(0, 0, 0, 0);
                    continue;
                }

                rectangles[j] = splittedRj[0];

                for (int c = 1; c < splittedRj.size(); ++c) {
                    rectangles.push_back(splittedRj[c]);
                }
            }

            rectangles.push_back(r);
        } else {
            if(setRec.find({curX, curY}) == setRec.end()) {
                if(i == 1) {
                    rectangles.push_back(r);
                } else {
                    rectangles.push_back(Rect(curX, curY, curX + k, curY + k));
                }

                setRec.insert({curX, curY});
            }
        }
    }

    long long area = 0;

    for (int i = 0; i < rectangles.size(); ++i) {
        area += (rectangles[i].x1 - rectangles[i].x0) * (rectangles[i].y1 - rectangles[i].y0);
    }

    cout << area;

    return 0;
}
